==> tuia-news-center-api-1.8.4.0-xt3-20190104.020501-1-sources.jar: cn/com/duiba/tuia/news/center/enums/loginReward/NewRewardSubType.java <==
package cn.com.duiba.tuia.news.center.enums.loginReward;

import com.google.common.collect.Maps;

import java.util.Arrays;
import java.util.Map;

/**
 * @author ElinZhou
 * @version $Id: AppType.java , v 0.1 2018/1/4 下午8:00 ElinZhou Exp $
 */
public enum NewRewardSubType {

    LOAD_1(1,10L,10L,10L,10L,10L,20L,30L);

    private Integer code;

    private Long x1;
    private Long x2;
    private Long x3;
    private Long x4;
    private Long x5;
    private Long y;
    private Long z;

    NewRewardSubType(Integer code, Long x1, Long x2, Long x3, Long x4, Long x5, Long y, Long z) {
        this.code = code;
        this.x1 = x1;
        this.x2 = x2;
        this.x3 = x3;
        this.x4 = x4;
        this.x5 = x5;
        this.y = y;
        this.z = z;
    }

    public Integer getCode() {
        return code;
    }

    public Long getX1() {
        return x1;
    }

    public Long getX2() {
        return x2;
    }

    public Long getX3() {
        return x3;
    }

    public Long getX4() {
        return x4;
    }

    public Long getX5() {
        return x5;
    }

    public Long getY() {
        return y;
    }

    public Long getZ() {
        return z;
    }


    private static final Map<Integer, NewRewardSubType> CACHE = Maps.uniqueIndex(Arrays.asList(NewRewardSubType
            .values()), NewRewardSubType::getCode);


    public static NewRewardSubType of(Integer aCode) {
        return CACHE.get(aCode);
    }


    public Long all() {
        return x1+x2+x3+x4+x5+y+z;
    }


    public Long getByDay(Integer day){
        switch (day){
            case 1:
                return x1;
            case 2:
                return x2;
            case 3:
                return x3;
            case 4:
                return x4;
            case 5:
                return x5;
                default:
                    return 0L;
        }
    }
}

==> tuia-news-center-api-1.8.8.0-xt3-20190121.023738-1-sources.jar: cn/com/duiba/tuia/news/center/enums/loginReward/NewRewardSubType.java <==
package cn.com.duiba.tuia.news.center.enums.loginReward;

import com.google.common.collect.Maps;

import java.util.Arrays;
import java.util.Map;

/**
 * @author ElinZhou
 * @version $Id: AppType.java , v 0.1 2018/1/4 下午8:00 ElinZhou Exp $
 */
public enum NewRewardSubType {

    LOAD_1(1,30L,15L,5L,5L,5L,30L,10L),

    LOAD_2(2,29L,5L,2L,2L,1L,50L,11L);

    private Integer code;

    private Long x1;
    private Long x2;
    private Long x3;
    private Long x4;
    private Long x5;
    private Long y;
    private Long z;

    NewRewardSubType(Integer code, Long x1, Long x2, Long x3, Long x4, Long x5, Long y, Long z) {
        this.code = code;
        this.x1 = x1;
        this.x2 = x2;
        this.x3 = x3;
        this.x4 = x4;
        this.x5 = x5;
        this.y = y;
        this.z = z;
    }

    public Integer getCode() {
        return code;
    }

    public Long getX1() {
        return x1;
    }

    public Long getX2() {
        return x2;
    }

    public Long getX3() {
        return x3;
    }

    public Long getX4() {
        return x4;
    }

    public Long getX5() {
        return x5;
    }

    public Long getY() {
        return y;
    }

    public Long getZ() {
        return z;
    }


    private static final Map<Integer, NewRewardSubType> CACHE = Maps.uniqueIndex(Arrays.asList(NewRewardSubType
            .values()), NewRewardSubType::getCode);


    public static NewRewardSubType of(Integer aCode) {
        NewRewardSubType newRewardSubType = CACHE.get(aCode);
        return null == newRewardSubType?LOAD_1:newRewardSubType;
    }


    public Long all() {
        return x1+x2+x3+x4+x5+y+z;
    }


    public Long getByDay(Integer day){
        switch (day){
            case 1:
                return x1;
            case 2:
                return x2;
            case 3:
                return x3;
            case 4:
                return x4;
            case 5:
                return x5;
                default:
                    return 0L;
        }
    }
}
